import names
import argparse

parser = argparse.ArgumentParser()
parser.add_argument("--gender", help="returning random male with specified gender", choices=['male','female'])

args = parser.parse_args()



def get_names_2():
    if args.gender == 'male':
        new_name = names.get_full_name('male')
    elif args.gender == 'female':
        new_name = names.get_full_name('female')
    else:
        new_name = names.get_full_name()

    print(f'{new_name} {len(new_name)}')


get_names_2()


import setuptools

setuptools.setup(
    name = 'give_name_TP',
    version = '1.0.0',
    description = "Generate random names + their lenght",
    long_description = 'long desct',
    long_description_content_type = 'text/markdown',
    nclude_package_data=True,
    keywords = 'random names',
    packages = setuptools.find_packages(),
    scripts = ['my_names2_pac/my_names.py', 'bin/my_names.bat'],
    install_requires = ['names']
)
